@@ -1,23 +1,23 @@
 # Copyright (c) HashiCorp, Inc.
 # SPDX-License-Identifier: BUSL-1.1
 
-Vagrant.require 'etc'
-Vagrant.require 'logger'
-Vagrant.require 'pathname'
-Vagrant.require 'stringio'
-Vagrant.require 'thread'
-Vagrant.require 'timeout'
+require 'etc'
+require 'logger'
+require 'pathname'
+require 'stringio'
+require 'thread'
+require 'timeout'
 
-Vagrant.require 'log4r'
-Vagrant.require 'net/ssh'
-Vagrant.require 'net/ssh/proxy/command'
-Vagrant.require 'net/scp'
+require 'log4r'
+require 'net/ssh'
+require 'net/ssh/proxy/command'
+require 'net/scp'
 
-Vagrant.require 'vagrant/util/ansi_escape_code_remover'
-Vagrant.require 'vagrant/util/file_mode'
-Vagrant.require 'vagrant/util/keypair'
-Vagrant.require 'vagrant/util/platform'
-Vagrant.require 'vagrant/util/retryable'
+require 'vagrant/util/ansi_escape_code_remover'
+require 'vagrant/util/file_mode'
+require 'vagrant/util/keypair'
+require 'vagrant/util/platform'
+require 'vagrant/util/retryable'
 
 module VagrantPlugins
   module CommunicatorSSH
@@ -458,7 +458,8 @@ module VagrantPlugins
         raise Vagrant::Errors::SSHNotReady if ssh_info.nil?
 
         # Default some options
-        opts[:retries] = 5 if !opts.key?(:retries)
+        opts[:retries] = ssh_info[:connect_retries] if !opts.key?(:retries)
+        opts[:retry_delay] = ssh_info[:connect_retry_delay] if !opts.key?(:retry_delay)
 
         # Set some valid auth methods. We disable the auth methods that
         # we're not using if we don't have the right auth info.
@@ -487,7 +488,7 @@ module VagrantPlugins
           timeout = 60
 
           @logger.info("Attempting SSH connection...")
-          connection = retryable(tries: opts[:retries], on: SSH_RETRY_EXCEPTIONS) do
+          connection = retryable(tries: opts[:retries], on: SSH_RETRY_EXCEPTIONS, sleep: opts[:retry_delay]) do
             Timeout.timeout(timeout) do
               begin
                 # This logger will get the Net-SSH log data for us.
@@ -539,7 +540,7 @@ module VagrantPlugins
         rescue Errno::EACCES
           # This happens on connect() for unknown reasons yet...
           raise Vagrant::Errors::SSHConnectEACCES
-        rescue Errno::ETIMEDOUT, Timeout::Error
+        rescue Errno::ETIMEDOUT, Timeout::Error, IO::TimeoutError
           # This happens if we continued to timeout when attempting to connect.
           raise Vagrant::Errors::SSHConnectionTimeout
         rescue Net::SSH::AuthenticationFailed
