@@ -2332,7 +2332,7 @@ enum
 
 /* Define CC and CFLAGS which were used to build this version of GMP */
 #define __GMP_CC "gcc"
-#define __GMP_CFLAGS " -I/opt/vagrant/embedded/include -fPIC"
+#define __GMP_CFLAGS " -I/opt/vagrant/embedded/include -fPIC -std=c17"
 
 /* Major version number is the value of __GNU_MP__ too, above. */
 #define __GNU_MP_VERSION            6
